import tokyocabinet.*;

public class TCHashDBTest {
  public static void main(String[] args) {
    HDB hdb = new HDB();

    if (!hdb.tune(131071, 4, 10, 0)) {
      int ecode = hdb.ecode();
      System.err.println("tune error: " + hdb.errmsg(ecode));
    }
    if (!hdb.open("casket.hdb", HDB.OWRITER |
                                HDB.OCREAT |
                                HDB.OTRUNC)) {
      int ecode = hdb.ecode();
      System.err.println("open error: " + hdb.errmsg(ecode));
    }

    if (!hdb.put("gunyara", "human being") ||
        !hdb.put("kiki", "cat") ||
        !hdb.put("moru", "guinea pig") ||
        !hdb.put("hamuwo", "hamster")) {
      int ecode = hdb.ecode();
      System.err.println("put error: " + hdb.errmsg(ecode));
    }

    String value = hdb.get("kiki");
    if (value != null) {
      System.out.println(value);
    } else {
      int ecode = hdb.ecode();
      System.err.println("get error: " + hdb.errmsg(ecode));
    }

    if (!hdb.out("gunyara")) {
      int ecode = hdb.ecode();
      System.err.println("out error: " + hdb.errmsg(ecode));
    }

    String key;
    hdb.iterinit();
    while ((key = hdb.iternext2()) != null) {
      value = hdb.get(key);
      if (value != null){
        System.out.println(key + ":" + value);
      }
    }

    System.out.println(hdb.path() + " " + hdb.rnum() + " records, " +
                       hdb.fsiz() + " bytes)");

    if (!hdb.close()) {
      int ecode = hdb.ecode();
      System.err.println("close error: " + hdb.errmsg(ecode));
    }

    hdb = new HDB();

    if (!hdb.open("casket.hdb", HDB.OWRITER |
                                HDB.OCREAT |
                                HDB.OTRUNC)) {
      int ecode = hdb.ecode();
      System.err.println("open error: " + hdb.errmsg(ecode));
    }

    if (!hdb.put("kiki", "nya-")) {
      int ecode = hdb.ecode();
      System.err.println("put error: " + hdb.errmsg(ecode));
    }
    if (!hdb.putkeep("kiki", "wan wan")) {
      int ecode = hdb.ecode();
      System.err.println("putkeep error: " + hdb.errmsg(ecode));
    }
    if (!hdb.putkeep("cameraski", "human being")) {
      int ecode = hdb.ecode();
      System.err.println("putkeep error: " + hdb.errmsg(ecode));
    }

    value = hdb.get("kiki");
    if (value != null) {
      System.out.println(value);
    } else {
      int ecode = hdb.ecode();
      System.err.println("get error: " + hdb.errmsg(ecode));
    }

    value = hdb.get("cameraski");
    if (value != null) {
      System.out.println(value);
    } else {
      int ecode = hdb.ecode();
      System.err.println("get error: " + hdb.errmsg(ecode));
    }

    if (!hdb.putcat("kiki", "nyan")) {
      int ecode = hdb.ecode();
      System.err.println("putcat error: " + hdb.errmsg(ecode));
    }

    value = hdb.get("kiki");
    if (value != null) {
      System.out.println(value);
    } else {
      int ecode = hdb.ecode();
      System.err.println("get error: " + hdb.errmsg(ecode));
    }

    for (int i = 0; i < 1000; i++) {
      if (!hdb.putasync("key" + i, "value" + i)) {
        int ecode = hdb.ecode();
        System.err.println("putasync error: " + hdb.errmsg(ecode));
      }
    }
    if (!hdb.sync()) {
      int ecode = hdb.ecode();
      System.err.println("sync error: " + hdb.errmsg(ecode));
    }

    value = hdb.get("key0");
    if (value != null) {
      System.out.println(value);
    } else {
      int ecode = hdb.ecode();
      System.err.println("get error: " + hdb.errmsg(ecode));
    }

    value = hdb.get("key999");
    if (value != null) {
      System.out.println(value);
    } else {
      int ecode = hdb.ecode();
      System.err.println("get error: " + hdb.errmsg(ecode));
    }

    if (!hdb.optimize(131071, 4, 10, 0)) {
      int ecode = hdb.ecode();
      System.err.println("optimize error: " + hdb.errmsg(ecode));
    }

    System.out.println("record number: " + hdb.rnum());
    if (!hdb.vanish()) {
      int ecode = hdb.ecode();
      System.err.println("vanish error: " + hdb.errmsg(ecode));
    }
    System.out.println("record number: " + hdb.rnum());

    for (int i = 0; i < 8; i++) {
      int counter;
      counter = hdb.addint("counter_int", 1);
      System.out.println(counter);
    }

    for (int i = 0; i < 8; i++) {
      double counter;
      counter = hdb.adddouble("counter_double", 3.14);
      System.out.println(counter);
    }

    if (!hdb.close()) {
      int ecode = hdb.ecode();
      System.err.println("close error: " + hdb.errmsg(ecode));
    }
  }
}
