#!/usr/bin/perl -w
use strict;
use warnings;
use TokyoCabinet;

my $hdb = TokyoCabinet::HDB->new();
unless ($hdb->tune(131071, 4, 10, 0)) {
  print('tune error: ', $hdb->errmsg(), "\n");
}

unless (!$hdb->open('casket.hdb', $hdb->OWRITER |
                                  $hdb->OCREAT |
                                  $hdb->OTRUNC)) {
  print('open error: ', $hdb->errmsg(), "\n");
}

unless ($hdb->put('gunyara', 'human being') and
        $hdb->put('kiki', 'cat') and
        $hdb->put('moru', 'guinea pig') and
        $hdb->put('hamuwo', 'hamster')) {
  print('put error: ', $hdb->errmsg(), "\n");
}

if ((my $value = $hdb->get('kiki'))) {
  print($value, "\n");
} else {
  print('get error: ', $hdb->errmsg(), "\n");
}

unless ($hdb->out('gunyara')) {
  print('out error: ', $hdb->errmsg(), "\n");
}

unless ($hdb->iterinit()) {
  print('iterinit error: ', $hdb->errmsg(), "\n");
} else {
  while (defined(my $key = $hdb->iternext())) {
    my $value = $hdb->get($key);
    if (defined($value)) {
      print("$key:$value\n");
    }
  }
}

print "${\$hdb->path()} (${\$hdb->rnum()} records, ${\$hdb->fsiz()} bytes)\n";

unless ($hdb->close()){
  print('close error: ', $hdb->errmsg());
}

$hdb = TokyoCabinet::HDB->new();
unless ($hdb->open('casket.hdb', $hdb->OWRITER |
                                 $hdb->OCREAT |
                                 $hdb->OTRUNC)) {
  print('open error: ', $hdb->errmsg(), "\n");
}

unless ($hdb->put('kiki', 'nya-')) {
  print('put error: ', $hdb->errmsg(), "\n");
}
unless ($hdb->putkeep('kiki', 'wan wan')) {
  print('putkeep error: ', $hdb->errmsg(), "\n");
}
unless ($hdb->putkeep('cameraski', 'human being')) {
  print('putkeep error: ', $hdb->errmsg(), "\n");
}

if ((my $value = $hdb->get('kiki'))) {
  print($value, "\n");
} else {
  print('get error: ', $hdb->errmsg(), "\n");
}

if ((my $value = $hdb->get('cameraski'))) {
  print($value, "\n");
} else {
  print('get error: ', $hdb->errmsg(), "\n");
}

if ($hdb->putcat('kiki', 'nyan')) {
  print('putcat error: ', $hdb->errmsg(), "\n");
}
if ((my $value = $hdb->get('kiki'))) {
  print($value, "\n");
} else {
  print('get error: ', $hdb->errmsg(), "\n");
}

for (my $i = 0; $i < 1000; $i++) {
  unless ($hdb->putasync("key$i", "value$i")) {
    print('putasync error: ', $hdb->errmsg(), "\n");
  }
}
unless ($hdb->sync()) {
  print('sync error: ', $hdb->errmsg(), "\n");
}

if ((my $value = $hdb->get('key0'))) {
  print($value, "\n");
} else {
  print('get error: ', $hdb->errmsg(), "\n");
}

if ((my $value = $hdb->get('key999'))) {
  print($value, "\n");
} else {
  print('get error: ', $hdb->errmsg(), "\n");
}

unless ($hdb->optimize(131071, 4, 10, 0)) {
  print('optimize error: ', $hdb->errmsg(), "\n");
}

print("record number: ${\$hdb->rnum()}\n");
unless ($hdb->vanish()) {
  print('vanish error: ', $hdb->errmsg(), "\n");
}
print("record number: ${\$hdb->rnum()}\n");

for (my $i = 0; $i < 8; $i++) {
  my $counter = $hdb->addint('counter_int', 1);
  print($counter, "\n");
}

for (my $i = 0; $i < 8; $i++) {
  my $counter = $hdb->adddouble('counter_double', 3.14);
  print($counter, "\n");
}

unless ($hdb->close()) {
  print('close error: ', $hdb->errmsg());
}
